@@ -7,7 +7,7 @@ from sphinx.application import Sphinx
 
 from .cq_core import cq_directive, cq_directive_vtk, rendering_code
 
-__version__ = "0.1.0"
+__version__ = "0.2.0"
 
 _ROOT_DIR = Path(__file__).absolute().parent
 
@@ -44,8 +44,13 @@ def setup(app: Sphinx):
 
         app._sphinxcontrib_cadquery_vtkjs_installed = True
 
-    app.add_directive("cq_plot", cq_directive)
-    app.add_directive("cadquery", cq_directive_vtk)
+    app.add_directive("cadquery-svg", cq_directive)
+    app.add_directive("cadquery-vtk", cq_directive_vtk)
+
+    app.add_directive("cq_plot", cq_directive)  # deprecated, use cadquery-svg
+    app.add_directive("cadquery", cq_directive_vtk)  # deprecated, use cadquery-vtk
+
+    app.add_config_value("cadquery_include_source", True, "env")
 
     return {
         "version": __version__,
